//
//  GLTimeZoneManager.h
//  GLUtilityKit
//
//  Created by Jeffrey Early on 4/12/09.
//  Copyright 2009 Early Innovations, LLC. All rights reserved.
//

#import <Cocoa/Cocoa.h>

// The shared time zone manager facilitates application-wide time zone changes.
// In theory Cocoa already does this, but it's broken.

extern NSString *defaultTimeZoneManagerOffset;
extern NSString *shouldUseComputerTimeZoneManagerDefault;
extern NSString *defaultTimeZoneManagerOffsetDidChangeNotification;

@interface GLTimeZoneManager : NSObject

// Use this singleton for an "app wide" time zone manager.
// Otherwise initialize your own copy.
+ (GLTimeZoneManager *) sharedTimeZoneManager;

/************************************************/
/*		Time Zone Accessors						*/
/************************************************/

#pragma mark -
#pragma mark Time Zone Accessors
#pragma mark

// Arrays of strings for the UI
@property(readonly) NSArray *timeZoneHours;
@property(readonly) NSArray *timeZoneMinutes;

// Corresponding selection indexes
@property NSUInteger selectedTimeZoneHourIndex;
@property NSUInteger selectedTimeZoneMinuteIndex;

@property BOOL shouldUseComputerTimeZone;
@property(copy) NSTimeZone *timeZone;

@property(readonly) NSDateFormatter *dateFormatter;
@property(readonly) NSDateFormatter *timeFormatter;

// Override these if you do not want to use the "shared" defaults.
@property(readwrite, copy, nonatomic) NSString *shouldUseComputerTimeZoneAutosaveName;
@property(readwrite, copy, nonatomic) NSString *defaultTimeZoneAutosaveName;

@end
